require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_spalternateurl',
  dscmeta_resource_friendly_name: 'SPAlternateUrl',
  dscmeta_resource_name: 'MSFT_SPAlternateUrl',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'SharePointDSC',
  dscmeta_module_version: '5.5.0',
  docs: 'The DSC SPAlternateUrl resource type.
         Automatically generated from version 5.5.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_timeout: {
      type:     'Optional[Integer]',
      desc:     'The maximum time in seconds to wait for the DSC resource to complete.',
      behaviour: :parameter,
    },
    dsc_url: {
      type: 'String',
      desc: 'The new alternate URL',

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_internal: {
      type: 'Optional[Boolean]',
      desc: 'Specifies if the URL has to be configured as internal',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'present', 'Absent', 'absent']]",
      desc: 'Present ensures the URL is set for this zone on this web app, Absent ensures it is removed',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_webappname: {
      type: 'String',
      desc: 'The name of the web application to apply the alternate URL to',

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_zone: {
      type: "Enum['Default', 'default', 'Intranet', 'intranet', 'Extranet', 'extranet', 'Custom', 'custom', 'Internet', 'internet']",
      desc: 'The Zone to use for the alternate URL',

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
