require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_spblobcachesettings',
  dscmeta_resource_friendly_name: 'SPBlobCacheSettings',
  dscmeta_resource_name: 'MSFT_SPBlobCacheSettings',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'SharePointDSC',
  dscmeta_module_version: '5.5.0',
  docs: 'The DSC SPBlobCacheSettings resource type.
         Automatically generated from version 5.5.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_timeout: {
      type:     'Optional[Integer]',
      desc:     'The maximum time in seconds to wait for the DSC resource to complete.',
      behaviour: :parameter,
    },
    dsc_zone: {
      type: "Enum['Default', 'default', 'Intranet', 'intranet', 'Internet', 'internet', 'Custom', 'custom', 'Extranet', 'extranet']",
      desc: 'The zone of the web application for which blob cache has to be configured',

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_maxsizeingb: {
      type: 'Optional[Integer[0, 65535]]',
      desc: 'The maximum size (in GB) of disk space the blob cache is allowed to use',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt16',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_webappurl: {
      type: 'String',
      desc: 'The URL of the web application',

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_enablecache: {
      type: 'Boolean',
      desc: 'Specify if the blob cache has to be enabled',


      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_location: {
      type: 'Optional[String]',
      desc: 'The location where the blob cache has to store its files',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_filetypes: {
      type: 'Optional[String]',
      desc: 'Specify the file types that must be stored by the blob cache',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_maxageinseconds: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'The maximum age (in seconds) that a browser caches a blob',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
  },
)
