require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_spdiagnosticloggingsettings',
  dscmeta_resource_friendly_name: 'SPDiagnosticLoggingSettings',
  dscmeta_resource_name: 'MSFT_SPDiagnosticLoggingSettings',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'SharePointDSC',
  dscmeta_module_version: '5.5.0',
  docs: 'The DSC SPDiagnosticLoggingSettings resource type.
         Automatically generated from version 5.5.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_timeout: {
      type:     'Optional[Integer]',
      desc:     'The maximum time in seconds to wait for the DSC resource to complete.',
      behaviour: :parameter,
    },
    dsc_logmaxdiskspaceusageenabled: {
      type: 'Optional[Boolean]',
      desc: 'Will the maximum disk space setting be enabled',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_eventlogfloodprotectionenabled: {
      type: 'Optional[Boolean]',
      desc: 'Protect event logs with Event Log Flood Protection',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_eventlogfloodprotectionquietperiod: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'What quiet period should reset the event log flood protection thresholds',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_appanalyticsautomaticuploadenabled: {
      type: 'Optional[Boolean]',
      desc: 'Should app analytics automatically be uploaded',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_downloaderrorreportingupdatesenabled: {
      type: 'Optional[Boolean]',
      desc: 'Should updates to error reporting tools be automatically downloaded',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_scripterrorreportingenabled: {
      type: 'Optional[Boolean]',
      desc: 'Is script error reporting enabled in this farm',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_logcutinterval: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'How many minutes of activity will a ULS log file leep in an individual file',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_scripterrorreportingrequireauth: {
      type: 'Optional[Boolean]',
      desc: 'Require users to be authenticated to allow script errors to be reported',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_customerexperienceimprovementprogramenabled: {
      type: 'Optional[Boolean]',
      desc: 'Should the customer experience program be enabled in this farm',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_eventlogfloodprotectiontriggerperiod: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'What is the time period that will trigger event log flood protection',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_errorreportingenabled: {
      type: 'Optional[Boolean]',
      desc: 'Should reporting of errors be enabled',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_scripterrorreportingdelay: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'What delay will be set before script error reporting is triggered',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_daystokeeplogs: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'How many days should ULS logs be kept for',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_logspaceingb: {
      type: 'Integer[0, 4294967295]',
      desc: 'The space in GB that should be used to store ULS logs',


      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_issingleinstance: {
      type: "Enum['Yes', 'yes']",
      desc: "Specifies the resource is a single instance, the value must be 'Yes'",

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_eventlogfloodprotectionthreshold: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'What is the event log flood protection threshold',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_errorreportingautomaticuploadenabled: {
      type: 'Optional[Boolean]',
      desc: 'Should error reports be automatically uploaded',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_eventlogfloodprotectionnotifyinterval: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'What interval should the event logs report a flood event',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_logpath: {
      type: 'String',
      desc: 'The physical path on each server to store ULS logs',


      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
