require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_spexcelserviceapp',
  dscmeta_resource_friendly_name: 'SPExcelServiceApp',
  dscmeta_resource_name: 'MSFT_SPExcelServiceApp',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'SharePointDSC',
  dscmeta_module_version: '5.5.0',
  docs: 'The DSC SPExcelServiceApp resource type.
         Automatically generated from version 5.5.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_timeout: {
      type:     'Optional[Integer]',
      desc:     'The maximum time in seconds to wait for the DSC resource to complete.',
      behaviour: :parameter,
    },
    dsc_workbookcache: {
      type: 'Optional[String]',
      desc: 'Specifies the local file system location of the cache that is used to store workbooks that are used by Excel Services Application.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_loadbalancingscheme: {
      type: "Optional[Enum['RoundRobin', 'roundrobin', 'Local', 'local', 'WorkbookURL', 'workbookurl']]",
      desc: 'Specifies the load-balancing schema that is used by the Excel Services Application Web service application to send requests to different back-end Excel Services Application computers.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_memorycachethreshold: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the percentage of the maximum private bytes that can be allocated to inactive objects.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_privatebytesmax: {
      type: 'Optional[Integer[-2147483648, 2147483647]]',
      desc: 'Specifies the maximum private bytes, in megabytes, that are used by Excel Services Application.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'SInt32',
      mof_is_embedded: false,
    },
    dsc_name: {
      type: 'String',
      desc: 'The name of the service application',

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_sessionsperusermax: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the maximum number of sessions allowed for a user.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_cachingofunusedfilesenable: {
      type: 'Optional[Boolean]',
      desc: 'Specifies that files that are no longer used by Excel Services Application can remain in the cache for later use.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_trustedfilelocations: {
      type: "Optional[Array[Struct[{
              locationtype => Enum['SharePoint', 'sharepoint', 'UNC', 'unc', 'HTTP', 'http'],
              description => Optional[String],
              requestdurationmax => Optional[Integer[0, 4294967295]],
              shortsessiontimeout => Optional[Integer[0, 4294967295]],
              udfsallowed => Optional[Boolean],
              restexternaldataallowed => Optional[Boolean],
              concurrentdatarequestspersessionmax => Optional[Integer[0, 4294967295]],
              address => Optional[String],
              externaldataallowed => Optional[Enum['None', 'none', 'Dcl', 'dcl', 'DclandEmbedded', 'dclandembedded']],
              manualextdatacachelifetime => Optional[Integer[0, 4294967295]],
              chartandimagesizemax => Optional[Integer[0, 4294967295]],
              workbooksizemax => Optional[Integer[0, 4294967295]],
              periodicextdatacachelifetime => Optional[Integer[0, 4294967295]],
              newworkbooksessiontimeout => Optional[Integer[0, 4294967295]],
              displaygranularextdataerrors => Optional[Boolean],
              includechildren => Optional[Boolean],
              sessiontimeout => Optional[Integer[0, 4294967295]],
              defaultworkbookcalcmode => Optional[Enum['File', 'file', 'Manual', 'manual', 'Auto', 'auto', 'AutoDataTables', 'autodatatables']],
              abortonrefreshonopenfail => Optional[Boolean],
              warnondatarefresh => Optional[Boolean],
              automaticvolatilefunctioncachelifetime => Optional[Integer[0, 4294967295]]
            }]]]",
      desc: 'Trusted file locations for the service app',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'MSFT_SPExcelFileLocation[]',
      mof_is_embedded: true,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_workbookcachesizemax: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the maximum allowable size, in megabytes, of an individual session.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_unusedobjectagemax: {
      type: 'Optional[Integer[-2147483648, 2147483647]]',
      desc: 'Specifies the maximum amount of time, in minutes, that objects not currently used in a session are kept in the memory cache.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'SInt32',
      mof_is_embedded: false,
    },
    dsc_externaldataconnectionlifetime: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the maximum number of seconds that an external data connection can remain open in the connection pool.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'present', 'Absent', 'absent']]",
      desc: 'Present ensures service app exists, absent ensures it is removed',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_crossdomainaccessallowed: {
      type: 'Optional[Boolean]',
      desc: 'Specifies that trusted workbooks and data connection files can be requested and rendered by Web Parts or pages that reside in other HTTP domains.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_terminateprocessonaccessviolation: {
      type: 'Optional[Boolean]',
      desc: 'Terminates Excel Services Application when an access violation occurs in the process.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_applicationpool: {
      type: 'String',
      desc: 'The name of the application pool to run the service app in',


      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_fileaccessmethod: {
      type: "Optional[Enum['UseImpersonation', 'useimpersonation', 'UseFileAccessAccount', 'usefileaccessaccount']]",
      desc: 'Specifies the authentication method that Excel Services Application uses to retrieve files.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_encrypteduserconnectionrequired: {
      type: "Optional[Enum['None', 'none', 'Connection', 'connection']]",
      desc: 'Requires that encryption is used between the end-user and the server running Excel Services Application.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_throttleaccessviolationspersitecollection: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies that if a workbook causes an access violation error on Excel Services Application, all files originating from that workbookâ??s site collection are blocked from loading for the specified period (in seconds).',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_sitecollectionanonymoussessionsmax: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the maximum number of anonymous sessions allowed per site collection.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_unattendedaccountapplicationid: {
      type: 'Optional[String]',
      desc: 'Specifies that the application ID that is used to look up the unattended service account credentials from the secure storage service that is specified by the UnattendedAccountSecureServiceAppName parameter.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
