require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_spinfopathformsserviceconfig',
  dscmeta_resource_friendly_name: 'SPInfoPathFormsServiceConfig',
  dscmeta_resource_name: 'MSFT_SPInfoPathFormsServiceConfig',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'SharePointDSC',
  dscmeta_module_version: '5.5.0',
  docs: 'The DSC SPInfoPathFormsServiceConfig resource type.
         Automatically generated from version 5.5.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_timeout: {
      type:     'Optional[Integer]',
      desc:     'The maximum time in seconds to wait for the DSC resource to complete.',
      behaviour: :parameter,
    },
    dsc_maxpostbackspersession: {
      type: 'Optional[Integer[0, 65535]]',
      desc: 'Maximum number of postback allowed per session',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt16',
      mof_is_embedded: false,
    },
    dsc_maxdataconnectiontimeout: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Sets the maximum connection timeout in milliseconds',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_allowuserformcrossdomaindataconnections: {
      type: 'Optional[Boolean]',
      desc: 'True sets the InfoPath Forms Service to allow Cross-Domain connections',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_allowembeddedsqlfordataconnections: {
      type: 'Optional[Boolean]',
      desc: 'True sets the InfoPath Forms Service to allow embedded SQL sonnections in Forms',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_activesessionstimeout: {
      type: 'Optional[Integer[0, 65535]]',
      desc: 'Timeout in minutes for active sessions',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt16',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'present', 'Absent', 'absent']]",
      desc: 'Present ensures the settings are applied',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_allowuserformbrowserenabling: {
      type: 'Optional[Boolean]',
      desc: 'True sets the InfoPath Forms Service to allow users to browse forms',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_defaultdataconnectiontimeout: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Sets the default connection timeout in milliseconds',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_alloweventpropagation: {
      type: 'Optional[Boolean]',
      desc: 'True enables the original performance optimization',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_maxuseractionsperpostback: {
      type: 'Optional[Integer[0, 65535]]',
      desc: 'Maximum number of actions that can be triggered per postback',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt16',
      mof_is_embedded: false,
    },
    dsc_maxsizeofuserformstate: {
      type: 'Optional[Integer[0, 65535]]',
      desc: 'Maximum size of user session data',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt16',
      mof_is_embedded: false,
    },
    dsc_requiresslfordataconnections: {
      type: 'Optional[Boolean]',
      desc: 'True sets the InfoPath Forms Service to require SSL for its connections',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_issingleinstance: {
      type: "Enum['Yes', 'yes']",
      desc: "Specifies the resource is a single instance, the value must be 'Yes'",

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_maxdataconnectionresponsesize: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Sets the maximum response size in kb for the user response',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_allowuserformbrowserrendering: {
      type: 'Optional[Boolean]',
      desc: 'True sets the InfoPath Forms Service to render forms in the browser',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_allowudcauthenticationfordataconnections: {
      type: 'Optional[Boolean]',
      desc: 'True sets the InfoPath Forms Service to allow User Defined connections',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
  },
)
