require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_sploglevel',
  dscmeta_resource_friendly_name: 'SPLogLevel',
  dscmeta_resource_name: 'MSFT_SPLogLevel',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'SharePointDSC',
  dscmeta_module_version: '5.5.0',
  docs: 'The DSC SPLogLevel resource type.
         Automatically generated from version 5.5.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_timeout: {
      type:     'Optional[Integer]',
      desc:     'The maximum time in seconds to wait for the DSC resource to complete.',
      behaviour: :parameter,
    },
    dsc_sploglevelsetting: {
      type: "Array[Struct[{
              eventlevel => Optional[Enum['None', 'none', 'ErrorCritical', 'errorcritical', 'Error', 'error', 'Warning', 'warning', 'Information', 'information', 'Verbose', 'verbose', 'Default', 'default']],
              name => Optional[String],
              tracelevel => Optional[Enum['None', 'none', 'Unexpected', 'unexpected', 'Monitorable', 'monitorable', 'High', 'high', 'Medium', 'medium', 'Verbose', 'verbose', 'VerboseEx', 'verboseex', 'Default', 'default']],
              area => Optional[String]
            }]]",
      desc: 'Collection of SPLogLevelItems to set',


      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'MSFT_SPLogLevelItem[]',
      mof_is_embedded: true,
    },
    dsc_name: {
      type: 'String',
      desc: 'Friendly Name used to reference this collection of log level settings',

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
  },
)
