require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_spoutgoingemailsettings',
  dscmeta_resource_friendly_name: 'SPOutgoingEmailSettings',
  dscmeta_resource_name: 'MSFT_SPOutgoingEmailSettings',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'SharePointDSC',
  dscmeta_module_version: '5.5.0',
  docs: 'The DSC SPOutgoingEmailSettings resource type.
         Automatically generated from version 5.5.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_timeout: {
      type:     'Optional[Integer]',
      desc:     'The maximum time in seconds to wait for the DSC resource to complete.',
      behaviour: :parameter,
    },
    dsc_usetls: {
      type: 'Optional[Boolean]',
      desc: 'Use TLS when connecting to the SMTP server (SharePoint 2016 and 2019 only)',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_replytoaddress: {
      type: 'String',
      desc: 'The email address that replies should be directed to',


      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_smtpport: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'The port which is used to connect to the SMTP server (SharePoint 2016 and 2019 only)',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_fromaddress: {
      type: 'String',
      desc: 'The from address to put on messages',


      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_webappurl: {
      type: 'String',
      desc: 'The URL of the web application. If you want to set the global settings use the Central Admin URL',

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_smtpserver: {
      type: 'String',
      desc: 'The SMTP server for outgoing mail',


      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_characterset: {
      type: 'String',
      desc: 'The character set to use on messages',


      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
