require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_spprojectservertimesheetsettings',
  dscmeta_resource_friendly_name: 'SPProjectServerTimeSheetSettings',
  dscmeta_resource_name: 'MSFT_SPProjectServerTimeSheetSettings',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'SharePointDSC',
  dscmeta_module_version: '5.5.0',
  docs: 'The DSC SPProjectServerTimeSheetSettings resource type.
         Automatically generated from version 5.5.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_timeout: {
      type:     'Optional[Integer]',
      desc:     'The maximum time in seconds to wait for the DSC resource to complete.',
      behaviour: :parameter,
    },
    dsc_url: {
      type: 'String',
      desc: 'The default zone URL of the Project site to set timesheet settings for',

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_enableovertimeandnonbillabletracking: {
      type: 'Optional[Boolean]',
      desc: 'Should timesheets allow tracking of overtime and non-billable work types',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_defaulttrackingunit: {
      type: "Optional[Enum['Days', 'days', 'Weeks', 'weeks']]",
      desc: 'What is the default tracking unit for timesheets',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_singleentrymode: {
      type: 'Optional[Boolean]',
      desc: 'Enable single entry mode?',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_defaultreportingunit: {
      type: "Optional[Enum['Hours', 'hours', 'Days', 'days']]",
      desc: 'What is the default reporting unit for timesheets',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_minhourspertimesheet: {
      type: 'Optional[Float]',
      desc: 'Minimum hours per timesheet',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Real32',
      mof_is_embedded: false,
    },
    dsc_enabletimesheetauditing: {
      type: 'Optional[Boolean]',
      desc: 'Enable timesheet auditing?',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_requirelineapprovalbeforetimesheetapproval: {
      type: 'Optional[Boolean]',
      desc: 'Require line approval before timesheet approval?',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_allownewpersonaltasks: {
      type: 'Optional[Boolean]',
      desc: 'Allow new personal tasks?',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_hoursinstandardweek: {
      type: 'Optional[Float]',
      desc: 'How many hours are in a standard timesheeet week?',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Real32',
      mof_is_embedded: false,
    },
    dsc_requiretaskstatusmanagerapproval: {
      type: 'Optional[Boolean]',
      desc: 'Require task status manager approval?',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_hoursinstandardday: {
      type: 'Optional[Float]',
      desc: 'How many hours are in a standard timesheeet day?',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Real32',
      mof_is_embedded: false,
    },
    dsc_defaulttimesheetcreationmode: {
      type: "Optional[Enum['CurrentTaskAssignments', 'currenttaskassignments', 'CurrentProjects', 'currentprojects', 'NoPrepopulation', 'noprepopulation']]",
      desc: 'What is the default mode for timesheets to be created in',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_fixedapprovalrouting: {
      type: 'Optional[Boolean]',
      desc: 'Enable fixed approval routing?',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_defaulttrackingmode: {
      type: "Optional[Enum['PercentComplete', 'percentcomplete', 'ActualDoneAndRemaining', 'actualdoneandremaining', 'HoursPerPeriod', 'hoursperperiod', 'FreeForm', 'freeform']]",
      desc: 'What is the default tracking mode for tasks?',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_allowfuturetimereporting: {
      type: 'Optional[Boolean]',
      desc: 'Allow future time reporting?',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_forcetrackingmodeforallprojects: {
      type: 'Optional[Boolean]',
      desc: 'Force project managers to use the specified tracking mode for each project?',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_maxhourspertimesheet: {
      type: 'Optional[Float]',
      desc: 'Maximum hours per timesheet',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Real32',
      mof_is_embedded: false,
    },
    dsc_allowtopleveltimereporting: {
      type: 'Optional[Boolean]',
      desc: 'Allow top-level time reporting?',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_maxhoursperday: {
      type: 'Optional[Float]',
      desc: 'Maximum hours per day',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Real32',
      mof_is_embedded: false,
    },
  },
)
