require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_spsearchcrawlrule',
  dscmeta_resource_friendly_name: 'SPSearchCrawlRule',
  dscmeta_resource_name: 'MSFT_SPSearchCrawlRule',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'SharePointDSC',
  dscmeta_module_version: '5.5.0',
  docs: 'The DSC SPSearchCrawlRule resource type.
         Automatically generated from version 5.5.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_timeout: {
      type:     'Optional[Integer]',
      desc:     'The maximum time in seconds to wait for the DSC resource to complete.',
      behaviour: :parameter,
    },
    dsc_certificatename: {
      type: 'Optional[String]',
      desc: 'The certificate used for this crawl rule (used for type CertificateRuleAccess)',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_ruletype: {
      type: "Optional[Enum['InclusionRule', 'inclusionrule', 'ExclusionRule', 'exclusionrule']]",
      desc: 'The type of the rule',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_crawlconfigurationrules: {
      type: "Optional[Array[Enum['FollowLinksNoPageCrawl', 'followlinksnopagecrawl', 'CrawlComplexUrls', 'crawlcomplexurls', 'CrawlAsHTTP', 'crawlashttp']]]",
      desc: 'The configuration options for this rule',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'present', 'Absent', 'absent']]",
      desc: 'Present if the crawl rule should exist, absent if it should not',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_authenticationtype: {
      type: "Optional[Enum['DefaultRuleAccess', 'defaultruleaccess', 'BasicAccountRuleAccess', 'basicaccountruleaccess', 'CertificateRuleAccess', 'certificateruleaccess', 'NTLMAccountRuleAccess', 'ntlmaccountruleaccess', 'FormRuleAccess', 'formruleaccess', 'CookieRuleAccess', 'cookieruleaccess', 'AnonymousAccess', 'anonymousaccess']]",
      desc: 'Authentication type used by the crawl rule',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_path: {
      type: 'String',
      desc: 'The name of the search service application',

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_serviceappname: {
      type: 'String',
      desc: 'The name of the search service application',


      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_authenticationcredentials: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'The credentials used for this crawl rule (used for types BasicAccountRuleAccess and NTLMAccountRuleAccess)',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
  },
)
