require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_spsearchresultsource',
  dscmeta_resource_friendly_name: 'SPSearchResultSource',
  dscmeta_resource_name: 'MSFT_SPSearchResultSource',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'SharePointDSC',
  dscmeta_module_version: '5.5.0',
  docs: 'The DSC SPSearchResultSource resource type.
         Automatically generated from version 5.5.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_timeout: {
      type:     'Optional[Integer]',
      desc:     'The maximum time in seconds to wait for the DSC resource to complete.',
      behaviour: :parameter,
    },
    dsc_connectionurl: {
      type: 'Optional[String]',
      desc: 'The URI to connect to the remote location',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'present', 'Absent', 'absent']]",
      desc: 'Present if the result source should exist, absent if it should not',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_query: {
      type: 'String',
      desc: 'The query to pass to the provider source',


      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_providertype: {
      type: 'String',
      desc: 'The provider type to use for the result source',


      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_scopeurl: {
      type: 'String',
      desc: "The URI of the site where to create the result source. Use 'Global' if ScopeName is SSA",

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_name: {
      type: 'String',
      desc: 'The name of the result source',

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_scopename: {
      type: "Enum['SSA', 'ssa', 'SPSite', 'spsite', 'SPWeb', 'spweb']",
      desc: 'The scope at which the Result Source will be created. Options are SSA, SPSite or SPWeb',

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_searchserviceappname: {
      type: 'String',
      desc: 'The name of the search service application to associate this result source with',


      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
