require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_spsearchserviceapp',
  dscmeta_resource_friendly_name: 'SPSearchServiceApp',
  dscmeta_resource_name: 'MSFT_SPSearchServiceApp',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'SharePointDSC',
  dscmeta_module_version: '5.5.0',
  docs: 'The DSC SPSearchServiceApp resource type.
         Automatically generated from version 5.5.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_timeout: {
      type:     'Optional[Integer]',
      desc:     'The maximum time in seconds to wait for the DSC resource to complete.',
      behaviour: :parameter,
    },
    dsc_fixfarmaccountpermissions: {
      type: 'Optional[Boolean]',
      desc: 'Should the permissions for the Farm account on the Search databases be corrected',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_searchcenterurl: {
      type: 'Optional[String]',
      desc: 'The URL of the enterprise search center site collection',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_defaultcontentaccessaccount: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'The default content access account for this search service app',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_errorcountallowed: {
      type: 'Optional[Integer[0, 65535]]',
      desc: 'Specifies the number of consecutive crawls where other errors were encountered before the item is deleted from the index',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt16',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'present', 'Absent', 'absent']]",
      desc: 'Present if the service app should exist, absent if it should not',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_errordeletecountallowed: {
      type: 'Optional[Integer[0, 65535]]',
      desc: 'Specifies the number of consecutive crawls where Access Denied or File Not Found errors were encountered before the item is deleted from the index',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt16',
      mof_is_embedded: false,
    },
    dsc_deleteunvisitedmethod: {
      type: 'Optional[Integer[0, 65535]]',
      desc: 'Specifies what items get deleted: 0 - All unvisited items, 1 - (Default) All unvisited items that have the same host as the start address, 2 - None of the unvisited items. You can specify the following three values:',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt16',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_cloudindex: {
      type: 'Optional[Boolean]',
      desc: 'Should this search service application be a cloud based service app',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_databaseserver: {
      type: 'Optional[String]',
      desc: 'The server that host the databases for this service application',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_usesqlauthentication: {
      type: 'Optional[Boolean]',
      desc: 'Should SQL Server authentication be used to connect to the database?',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_alertsenabled: {
      type: 'Optional[Boolean]',
      desc: 'Should alerts be enabled for this search service application',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_databasename: {
      type: 'Optional[String]',
      desc: 'The name of the database (noting that some search databases will use this as a prefix)',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_applicationpool: {
      type: 'String',
      desc: 'The application pool that it should run in',


      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_proxyname: {
      type: 'Optional[String]',
      desc: 'The proxy name, if not specified will be /Name of service app/ Proxy',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_databasecredentials: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'If using SQL authentication, the SQL credentials to use to connect to the instance',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_errordeleteintervalallowed: {
      type: 'Optional[Integer[0, 65535]]',
      desc: 'Specifies the number of hours since the first Access Denied or File Not Found errors were encountered in a crawl before the item is deleted from the index',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt16',
      mof_is_embedded: false,
    },
    dsc_name: {
      type: 'String',
      desc: 'The name of the search service application',

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_recrawlerrorcount: {
      type: 'Optional[Integer[0, 65535]]',
      desc: 'Specifies the number of consecutive crawls in which errors were encountered while fetching changes from the SharePoint content database',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt16',
      mof_is_embedded: false,
    },
    dsc_recrawlerrorinterval: {
      type: 'Optional[Integer[0, 65535]]',
      desc: 'Specifies the number of hours since the first error were encountered while fetching changes from the SharePoint content database',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt16',
      mof_is_embedded: false,
    },
    dsc_errorintervalallowed: {
      type: 'Optional[Integer[0, 65535]]',
      desc: 'Specifies the number of hours since the first other errors were encountered in a crawl before the item is deleted from the index',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt16',
      mof_is_embedded: false,
    },
  },
)
