require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_spselfservicesitecreation',
  dscmeta_resource_friendly_name: 'SPSelfServiceSiteCreation',
  dscmeta_resource_name: 'MSFT_SPSelfServiceSiteCreation',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'SharePointDSC',
  dscmeta_module_version: '5.5.0',
  docs: 'The DSC SPSelfServiceSiteCreation resource type.
         Automatically generated from version 5.5.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_timeout: {
      type:     'Optional[Integer]',
      desc:     'The maximum time in seconds to wait for the DSC resource to complete.',
      behaviour: :parameter,
    },
    dsc_userexperienceversion: {
      type: "Optional[Enum['Modern', 'modern', 'Classic', 'classic', 'Latest', 'latest']]",
      desc: 'Specifies the if the site collection has to be created as modern or classic site (SP2019 only)',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_alternateurl: {
      type: 'Optional[String]',
      desc: 'Specifies the URL of the web application in which site collections have to be created (SP2019 only)',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_customformurl: {
      type: 'Optional[String]',
      desc: 'Specifies a custom form URL to use for Self Service Site Creation. This is only used when CreateIndividualSite is true. Must be an absolute URL or empty to use built in form (_layouts/_layouts/15/scsignup.aspx)',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_policyoption: {
      type: "Optional[Enum['MustHavePolicy', 'musthavepolicy', 'CanHavePolicy', 'canhavepolicy', 'NotHavePolicy', 'nothavepolicy']]",
      desc: 'Specifies what site classification should be displayed',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_webappurl: {
      type: 'String',
      desc: 'The url of the web application',

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_enabled: {
      type: 'Boolean',
      desc: 'Specifies if users are allowed to create site collections or not',


      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_requiresecondarycontact: {
      type: 'Optional[Boolean]',
      desc: 'Specifies if users needs to provide one or more additional site administrators',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_showstartasitemenuitem: {
      type: 'Optional[Boolean]',
      desc: 'Should the Start a Site link be displayed. Must be false or not specified if Enabled is false',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_managedpath: {
      type: 'Optional[String]',
      desc: 'Specifies the managed path in which site collections have to be created (SP2019 only)',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_parentsiteurl: {
      type: 'Optional[String]',
      desc: 'Specifies the URL of the parent site where new sites are to be created. This is only used when CreateIndividualSite is true. Use [%userid%] to represent the ID of the user who is creating the site, for example: /projects/[%userid%]',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_onlineenabled: {
      type: 'Optional[Boolean]',
      desc: 'Specifies if site collections are created in SharePoint Online in a hybrid configuration. Hybrid configuration needs to be caried out seperately using the Hybrid Picker',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_createindividualsite: {
      type: 'Optional[Boolean]',
      desc: 'Should Self Service Site Creation create an individual Site, false for a Site Collection',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_quotatemplate: {
      type: 'Optional[String]',
      desc: 'The quota template to apply to new site collections. Specify null to not apply any qouta template',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
