require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_sptrustedidentitytokenissuer',
  dscmeta_resource_friendly_name: 'SPTrustedIdentityTokenIssuer',
  dscmeta_resource_name: 'MSFT_SPTrustedIdentityTokenIssuer',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'SharePointDSC',
  dscmeta_module_version: '5.5.0',
  docs: 'The DSC SPTrustedIdentityTokenIssuer resource type.
         Automatically generated from version 5.5.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_timeout: {
      type:     'Optional[Integer]',
      desc:     'The maximum time in seconds to wait for the DSC resource to complete.',
      behaviour: :parameter,
    },
    dsc_identifierclaim: {
      type: 'String',
      desc: 'Identity claim type that uniquely identifies the user',


      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_description: {
      type: 'String',
      desc: 'Description of the SPTrustedIdentityTokenIssuer',


      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_usewreplyparameter: {
      type: 'Optional[Boolean]',
      desc: 'WReply parameter allows SharePoint to specify the return URL to the 3rd party STS upon successful authentication',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_name: {
      type: 'String',
      desc: 'Name of the SPTrustedIdentityTokenIssuer',

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'present', 'Absent', 'absent']]",
      desc: 'Present if the SPTrustedIdentityTokenIssuer should be created, or Absent if it should be removed',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_signingcertificatethumbprint: {
      type: 'Optional[String]',
      desc: 'Specify the thumbprint of the signing certificate, which must be located in certificate store LocalMachine\My',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_signouturl: {
      type: 'Optional[String]',
      desc: 'Required for OIDC trust: specify the sign-out URL of the issuer',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_providersignouturi: {
      type: 'Optional[String]',
      desc: 'Sign-out URL',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_claimprovidername: {
      type: 'Optional[String]',
      desc: 'Name of a claims provider to set with this SPTrustedIdentityTokenIssuer',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_claimsmappings: {
      type: 'Array[Struct[{
              localclaimtype => Optional[String],
              name => Optional[String],
              incomingclaimtype => String,
            }]]',
      desc: 'Array of MSFT_SPClaimTypeMapping to use with cmdlet New-SPClaimTypeMapping',


      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'MSFT_SPClaimTypeMapping[]',
      mof_is_embedded: true,
    },
    dsc_authorizationendpointuri: {
      type: 'Optional[String]',
      desc: 'Required for OIDC trust: specify the sign-in URL of the issuer',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_realm: {
      type: 'Optional[String]',
      desc: 'Default Realm that is passed to identity provider',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_signinurl: {
      type: 'Optional[String]',
      desc: 'URL of the identity provider where user is redirected to for authentication',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_defaultclientidentifier: {
      type: 'Optional[String]',
      desc: 'Required for OIDC trust: specify the client identifier of the issuer',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_signingcertificatefilepath: {
      type: 'Optional[String]',
      desc: 'Specify the file path to the signing certificate if it is not stored in the local certificate store already',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_registeredissuername: {
      type: 'Optional[String]',
      desc: 'Required for OIDC trust: Specify the identity of the issuer',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
