require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_spwebappclientcallablesettings',
  dscmeta_resource_friendly_name: 'SPWebAppClientCallableSettings',
  dscmeta_resource_name: 'MSFT_SPWebAppClientCallableSettings',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'SharePointDSC',
  dscmeta_module_version: '5.5.0',
  docs: 'The DSC SPWebAppClientCallableSettings resource type.
         Automatically generated from version 5.5.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_timeout: {
      type:     'Optional[Integer]',
      desc:     'The maximum time in seconds to wait for the DSC resource to complete.',
      behaviour: :parameter,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_requestxmlmaxdepth: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: "Sets the maximum depth of the request XML that is sent by the client measured in 'tag' count",


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_enablerequestusage: {
      type: 'Optional[Boolean]',
      desc: 'Sets a Boolean value that specifies whether to log usage data or not',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_proxylibrariestoinclude: {
      type: 'Optional[Array[Struct[{
              assemblyname => String,
              supportappauthentication => Optional[Boolean],
            }]]]',
      desc: 'A list of proxy libraries to add. Proxy libraries not in this list will be kept',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'MSFT_SPProxyLibraryEntry[]',
      mof_is_embedded: true,
    },
    dsc_proxylibraries: {
      type: 'Optional[Array[Struct[{
              assemblyname => String,
              supportappauthentication => Optional[Boolean],
            }]]]',
      desc: 'A list of proxy libraries to set. Those not in this list will be removed',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'MSFT_SPProxyLibraryEntry[]',
      mof_is_embedded: true,
    },
    dsc_requestusageexecutiontimethreshold: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Sets the threshold in milliseconds for logging csom request usage data ',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_enablexsdvalidation: {
      type: 'Optional[Boolean]',
      desc: 'Sets a Boolean value that specifies whether to enable XSD validation against an XML request or not',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_logactionsifhasrequestexception: {
      type: 'Optional[Boolean]',
      desc: 'Sets a Boolean value that specifies whether to log usage data when request has an exception or not',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_maxresourcesperrequest: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Sets the maximum number of internal SPRequest objects that can be included in one request',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_proxylibrariestoexclude: {
      type: 'Optional[Array[String]]',
      desc: 'A list of proxy libraries to remove. Proxy libraries not in this list will be kept',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_webappurl: {
      type: 'String',
      desc: 'The URL of the web application to set blocked file types for',

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_maxobjectpaths: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Sets the maximum number of object paths that can be used within one request',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_enablestacktrace: {
      type: 'Optional[Boolean]',
      desc: 'Sets a Boolean value that specifies whether the server can send stack trace data to the client',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_executiontimeout: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Sets the execution timeout for the client request in minutes',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
  },
)
