require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_spwebappgeneralsettings',
  dscmeta_resource_friendly_name: 'SPWebAppGeneralSettings',
  dscmeta_resource_name: 'MSFT_SPWebAppGeneralSettings',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'SharePointDSC',
  dscmeta_module_version: '5.5.0',
  docs: 'The DSC SPWebAppGeneralSettings resource type.
         Automatically generated from version 5.5.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_timeout: {
      type:     'Optional[Integer]',
      desc:     'The maximum time in seconds to wait for the DSC resource to complete.',
      behaviour: :parameter,
    },
    dsc_alertslimit: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'What is the maximum number of alerts that a user can create in this web app',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_securityvalidation: {
      type: 'Optional[Boolean]',
      desc: 'Is security validation enforced in this web app',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_rss: {
      type: 'Optional[Boolean]',
      desc: 'Should RSS feeds be enabled in this web app',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_secondstagerecyclebinquota: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'How much content does the second stage recycle bin keep content for',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_allowonlinewebpartcatalog: {
      type: 'Optional[Boolean]',
      desc: 'Should the Online WebPart Gallery be enabled for this web app',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_presenceenabled: {
      type: 'Optional[Boolean]',
      desc: 'Is Skype for Business presence enabled for this web app',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_maximumuploadsize: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'What is the maximum file upload size for this web app (in MB)',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_blogapiauthenticated: {
      type: 'Optional[Boolean]',
      desc: 'Is authentication required for the blog API',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_blogapi: {
      type: 'Optional[Boolean]',
      desc: 'Should the Blog API be enabled in this web app',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_alerts: {
      type: 'Optional[Boolean]',
      desc: 'Should alerts be enabled for this web app',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_recyclebincleanupenabled: {
      type: 'Optional[Boolean]',
      desc: 'Is automatic cleanup of the recycle bin enabled in this web app',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_recyclebinretentionperiod: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'How many days does the recycle bin keep content for',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_securityvalidationtimeoutminutes: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Number of minutes security validation will expire if securityvalidationexpires is set',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_timezone: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'The timezone code to use for this web app. A full list is at https://msdn.microsoft.com/en-us/library/office/microsoft.sharepoint.spregionalsettings.timezones.aspx',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_browserfilehandling: {
      type: "Optional[Enum['Strict', 'strict', 'Permissive', 'permissive']]",
      desc: 'What file handling mode should be used in this web app - strict or permissive',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_customerexperienceprogram: {
      type: 'Optional[Boolean]',
      desc: 'Should the customer experience program be enabled in this web app',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_defaultquotatemplate: {
      type: 'Optional[String]',
      desc: 'What is the default quota template for this web app',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_recyclebinenabled: {
      type: 'Optional[Boolean]',
      desc: 'Is the recycle bin enabled in this web application',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_webappurl: {
      type: 'String',
      desc: 'The URL of the web app to set the general settings for',

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_selfservicesitecreationenabled: {
      type: 'Optional[Boolean]',
      desc: 'Should Self Service Site Creation be enabled',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_securityvalidationexpires: {
      type: 'Optional[Boolean]',
      desc: 'Does security validation expire after a set time',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
  },
)
