require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_spwebapphttpthrottlingmonitor',
  dscmeta_resource_friendly_name: 'SPWebAppHttpThrottlingMonitor',
  dscmeta_resource_name: 'MSFT_SPWebAppHttpThrottlingMonitor',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'SharePointDSC',
  dscmeta_module_version: '5.5.0',
  docs: 'The DSC SPWebAppHttpThrottlingMonitor resource type.
         Automatically generated from version 5.5.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_timeout: {
      type:     'Optional[Integer]',
      desc:     'The maximum time in seconds to wait for the DSC resource to complete.',
      behaviour: :parameter,
    },
    dsc_isdescending: {
      type: 'Optional[Boolean]',
      desc: 'Specifies that this counter is interpreted in descending order',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_counterinstance: {
      type: 'Optional[String]',
      desc: 'Specifies the instance of the performance counter',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'present', 'Absent', 'absent']]",
      desc: 'Present if the throttling monitor should exist, absent if it should not',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_category: {
      type: 'String',
      desc: 'Specifies the name of the performance counter category',


      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_healthscorebuckets: {
      type: 'Optional[Array[Integer[0, 4294967295]]]',
      desc: 'Specifies bucket ranges to use in determining the calculation of the server Health Score for this counter',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32[]',
      mof_is_embedded: false,
    },
    dsc_webappurl: {
      type: 'String',
      desc: 'The URL of the web app to set the throttling monitor for',

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_counter: {
      type: 'String',
      desc: 'Specifies the name of the performance counter',


      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
