require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_spwebapppolicy',
  dscmeta_resource_friendly_name: 'SPWebAppPolicy',
  dscmeta_resource_name: 'MSFT_SPWebAppPolicy',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'SharePointDSC',
  dscmeta_module_version: '5.5.0',
  docs: 'The DSC SPWebAppPolicy resource type.
         Automatically generated from version 5.5.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_timeout: {
      type:     'Optional[Integer]',
      desc:     'The maximum time in seconds to wait for the DSC resource to complete.',
      behaviour: :parameter,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_memberstoinclude: {
      type: "Optional[Array[Struct[{
              username => String,
              identitytype => Optional[Enum['Claims', 'claims', 'Native', 'native']],
              actassystemaccount => Optional[Boolean],
              permissionlevel => Optional[Array[Enum['Deny All', 'deny all', 'Deny Write', 'deny write', 'Full Read', 'full read', 'Full Control', 'full control']]],
            }]]]",
      desc: 'List of all accounts that must be in the Web Policy group',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'MSFT_SPWebPolicyPermissions[]',
      mof_is_embedded: true,
    },
    dsc_webappurl: {
      type: 'String',
      desc: 'The URL of the web application',

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_setcacheaccountspolicy: {
      type: 'Optional[Boolean]',
      desc: 'Include the Cache Accounts in the policy or not',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_members: {
      type: "Optional[Array[Struct[{
              username => String,
              identitytype => Optional[Enum['Claims', 'claims', 'Native', 'native']],
              actassystemaccount => Optional[Boolean],
              permissionlevel => Optional[Array[Enum['Deny All', 'deny all', 'Deny Write', 'deny write', 'Full Read', 'full read', 'Full Control', 'full control']]],
            }]]]",
      desc: 'Exact list of accounts that will have to get Web Policy permissions',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'MSFT_SPWebPolicyPermissions[]',
      mof_is_embedded: true,
    },
    dsc_memberstoexclude: {
      type: "Optional[Array[Struct[{
              username => String,
              identitytype => Optional[Enum['Claims', 'claims', 'Native', 'native']],
              actassystemaccount => Optional[Boolean],
              permissionlevel => Optional[Array[Enum['Deny All', 'deny all', 'Deny Write', 'deny write', 'Full Read', 'full read', 'Full Control', 'full control']]],
            }]]]",
      desc: 'List of all accounts that are not allowed to have any Web Policy permissions',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'MSFT_SPWebPolicyPermissions[]',
      mof_is_embedded: true,
    },
  },
)
