require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_spwebappsuitebar',
  dscmeta_resource_friendly_name: 'SPWebAppSuiteBar',
  dscmeta_resource_name: 'MSFT_SPWebAppSuiteBar',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'SharePointDSC',
  dscmeta_module_version: '5.5.0',
  docs: 'The DSC SPWebAppSuiteBar resource type.
         Automatically generated from version 5.5.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_timeout: {
      type:     'Optional[Integer]',
      desc:     'The maximum time in seconds to wait for the DSC resource to complete.',
      behaviour: :parameter,
    },
    dsc_suitebarbrandingelementhtml: {
      type: 'Optional[String]',
      desc: 'SP2013+: HTML to inject in the left hand-side of the Suite Bar. Only works in classic pages with a SharePoint 2013 master page in SharePoint 2016 and newer.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_suitenavbrandinglogonavigationurl: {
      type: 'Optional[String]',
      desc: 'SP2016+: Url to take the users to when the suite bar logo is clicked. This only works on classic pages for SP2019 and newer.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_suitenavbrandinglogourl: {
      type: 'Optional[String]',
      desc: 'SP2016+: URL of the logo for the Suite Bar. This only works on classic pages for SP2019 and newer.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_webappurl: {
      type: 'String',
      desc: 'The URL of the web application',

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_suitenavbrandinglogotitle: {
      type: 'Optional[String]',
      desc: 'SP2016+: Alternative text for the Suite Bar Logo. This only works on classic pages for SP2019 and newer.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_suitenavbrandingtext: {
      type: 'Optional[String]',
      desc: 'SP2016+: Text to display at the left hand side of the suite bar. No built in support of showing this on web pages in SP2019 and newer.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
