require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_spwebappthrottlingsettings',
  dscmeta_resource_friendly_name: 'SPWebAppThrottlingSettings',
  dscmeta_resource_name: 'MSFT_SPWebAppThrottlingSettings',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'SharePointDSC',
  dscmeta_module_version: '5.5.0',
  docs: 'The DSC SPWebAppThrottlingSettings resource type.
         Automatically generated from version 5.5.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_timeout: {
      type:     'Optional[Integer]',
      desc:     'The maximum time in seconds to wait for the DSC resource to complete.',
      behaviour: :parameter,
    },
    dsc_adminthreshold: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'What is the list view threshold for site administrators',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_eventhandlersenabled: {
      type: 'Optional[Boolean]',
      desc: 'Are event handlers enabled in the web application',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_changelogenabled: {
      type: 'Optional[Boolean]',
      desc: 'Is the change log enabled for this web app',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_allowobjectmodeloverride: {
      type: 'Optional[Boolean]',
      desc: 'Should object model code be able to be override the list view threshold',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_listviewlookupthreshold: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'What is the maximum number of lookup fields in a single list view',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_requestthrottling: {
      type: 'Optional[Boolean]',
      desc: 'Is request throttling enabled on this web app',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_changelogexpirydays: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'How many days does the change log store data for',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_webappurl: {
      type: 'String',
      desc: 'The URL of the web application',

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_happyhourenabled: {
      type: 'Optional[Boolean]',
      desc: 'Should the happy hour window be enabled for this web app',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_uniquepermissionthreshold: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'What is the limit for unique permissions on a single object in this web app',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_listviewthreshold: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'What should the list view threshold for this site be set to',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_happyhour: {
      type: 'Optional[Struct[{
              duration => Optional[Integer[0, 4294967295]],
              hour => Optional[Integer[0, 4294967295]],
              minute => Optional[Integer[0, 4294967295]],
            }]]',
      desc: 'The time window for happy hour',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'MSFT_SPWebApplicationHappyHour',
      mof_is_embedded: true,
    },
  },
)
