require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_spwordautomationserviceapp',
  dscmeta_resource_friendly_name: 'SPWordAutomationServiceApp',
  dscmeta_resource_name: 'MSFT_SPWordAutomationServiceApp',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'SharePointDSC',
  dscmeta_module_version: '5.5.0',
  docs: 'The DSC SPWordAutomationServiceApp resource type.
         Automatically generated from version 5.5.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_timeout: {
      type:     'Optional[Integer]',
      desc:     'The maximum time in seconds to wait for the DSC resource to complete.',
      behaviour: :parameter,
    },
    dsc_keepalivetimeout: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'How long is the keep alive timeout set to for the service app',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_timebeforeconversionismonitored: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'How long can a conversion be run before it becomes monitored',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_numberofconversionsperprocess: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'How many document conversions should be included in a single process',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_disablebinaryfilescan: {
      type: 'Optional[Boolean]',
      desc: 'Should binary file scans be disabled',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'present', 'Absent', 'absent']]",
      desc: 'Present to ensure the app exists, absent to ensure that it does not',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_disableembeddedfonts: {
      type: 'Optional[Boolean]',
      desc: 'Should embedded fonts be disabled',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_name: {
      type: 'String',
      desc: 'THe name of the service application',

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_applicationpool: {
      type: 'Optional[String]',
      desc: 'The name of the application pool to run the service app in',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_databaseserver: {
      type: 'Optional[String]',
      desc: 'The name of the server that will host the database',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_usesqlauthentication: {
      type: 'Optional[Boolean]',
      desc: 'Should SQL Server authentication be used to connect to the database?',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_recyclethreshold: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'What is the recycle threshold for this service app',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_databasename: {
      type: 'Optional[String]',
      desc: 'The name of the database for the service app',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_maximumconversionattempts: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'What is the maximum number of attempts to convert a document',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_conversionprocesses: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'How many conversion processes can be run at once',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_maximumsyncconversionrequests: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'What is the maximum number of sync conversion requests for the service app',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_databasecredentials: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'If using SQL authentication, the SQL credentials to use to connect to the instance',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_jobconversionfrequency: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'How frequently should new jobs be started from the queue (in minutes)',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_supportedfileformats: {
      type: "Optional[Array[Enum['docx', 'doc', 'mht', 'rtf', 'xml']]]",
      desc: 'The list of supported file types',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_addtodefault: {
      type: 'Optional[Boolean]',
      desc: 'Should the service application be added to the default proxy group?',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_maximumconversiontime: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'What is the maximum time in seconds for a document conversion to be allowed to run',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_maximummemoryusage: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'What is the maximum amount of memory the service app should use (in MB)',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
  },
)
